@@ -1,4 +1,4 @@
-# $Id: krige.cv.q,v 1.14 2006-02-10 19:01:07 edzer Exp $
+# $Id: krige.cv.q,v 1.15 2006-05-15 16:26:54 edzer Exp $
 
 if (!isGeneric("krige.cv"))
 	setGeneric("krige.cv", function(formula, locations, ...)
@@ -9,18 +9,18 @@ krige.cv.locations = function (formula, locations, data = sys.frame(sys.parent()
 	nfold = nrow(data), verbose = FALSE) {
 
 	gstat.cv(gstat(g = NULL, id = "var1", formula = formula, locations = 
-		locations, data = data, model = model, beta = beta, nmax = Inf, 
-		nmin = 0, maxdist = maxdist, ...), nfold = nfold, verbose = verbose)
+		locations, data = data, model = model, beta = beta, nmax = nmax, 
+		nmin = nmin, maxdist = maxdist, ...), nfold = nfold, verbose = verbose)
 }
 setMethod("krige.cv", c("formula", "formula"), krige.cv.locations)
 
 krige.cv.spatial = function (formula, locations, model = NULL, ..., beta = NULL,
-	nmax = Inf, nmin = 0, maxdist = Inf, nfold = nrow(data), verbose = FALSE) {
+	nmax = Inf, nmin = 0, maxdist = Inf, nfold = nrow(locations), verbose = FALSE) {
 
 	# data = locations 
 	gstat.cv(gstat(g = NULL, id = "var1", formula = formula,
 		data = locations, model = model, beta =
-		beta, nmax = Inf, nmin = 0, maxdist = maxdist,
+		beta, nmax = nmax, nmin = nmin, maxdist = maxdist,
 		...), nfold = nfold, verbose = verbose)
 }
 setMethod("krige.cv", c("formula", "Spatial"), krige.cv.spatial)
